---
name: Bug Report
about: Report a bug
# based on matplotlib issue template
---

<!--To help us understand and resolve your issue, please fill out the form to the best of your ability.-->
<!--You can feel free to delete the sections that do not apply.-->

### Bug report

**Bug summary**

<!--A short 1-2 sentences that succinctly describes the bug-->

**Code for reproduction**

<!--A minimum code snippet required to reproduce the bug.
Please make sure to minimize the number of dependencies required, and provide
any necessary plotted data.

```python
# Paste your code here
#
#
```

**Actual outcome**

<!--The output produced by the above code, which may be a screenshot, console output, etc.-->

**Expected outcome**

<!--A description of the expected outcome from the code snippet-->
<!--If this used to work in an earlier version of Matplotlib, please note the version it used to work on-->

**Version Info**
<!--Please specify your platform and versions of the relevant libraries you are using:-->
  * Operating system:
  * Matplotlib version:
  * Matplotlib backend (`print(matplotlib.get_backend())`):
  * Python version:
  * Jupyter version (if applicable):
  * Other libraries:
